@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003 Julian Rockey <linux@jrockey.com>
+ * Copyright (C) 2003 Julian Rockey <kde@jrockey.com>
  */
 
 #include "kdedcoptest.h"
@@ -22,8 +22,8 @@ static KCmdLineOptions options[] =
 int main(int argc, char **argv)
 {
     KAboutData about("kdedcoptest", I18N_NOOP("KDEDcopTest"), version, description,
-                     KAboutData::License_GPL, "(C) 2003 Julian Rockey", 0, 0, "linux@jrockey.com");
-    about.addAuthor( "Julian Rockey", 0, "linux@jrockey.com" );
+                     KAboutData::License_GPL, "(C) 2003 Julian Rockey", 0, 0, "kde@jrockey.com");
+    about.addAuthor( "Julian Rockey", 0, "kde@jrockey.com" );
     KCmdLineArgs::init(argc, argv, &about);
     KCmdLineArgs::addCmdLineOptions( options );
     KApplication app;
