@@ -18,13 +18,17 @@ public:
     static Slot *new_FloatSlot(qt_floatCallback);
     static Slot *new_QRectSlot(qt_QRectCallback);
     static Slot *new_QSizeSlot(qt_QSizeCallback);
+    static Slot *new_QStringSlot(qt_QStringCallback);
     static Slot *new_UserDataSlot(qt_UserDataCallback, void * userData);
+
+       
 public slots:
     void intSlot(int i);
     void voidSlot();
     void floatSlot(float f);
     void QRectSlot(QRect f);
     void QSizeSlot(QSize f);
+    void QStringSlot(const QString &s);
     void UserDataSlot();
     void UserDataSlot(int);
     void UserDataSlot(void *);
@@ -36,6 +40,7 @@ private:
         qt_floatCallback floatf;
         qt_QRectCallback qrectf;
         qt_QSizeCallback qsizef;
+	qt_QStringCallback qss;
         qt_UserDataCallback userdataf;
     };
     void * userData;
