@@ -359,11 +359,46 @@ public class Invocation {
 		return invoke(arguments);
 	}
 
+	/** Invoke the named void method on the target object with no arguments. Returns true
+		if the target method was successfully invoked. */
+	public static boolean invoke(long target, String methodName) throws NoSuchMethodException, ClassNotFoundException  {
+		Method	method;
+		Object onThis = qtjava.objectForQtKey(target, "QObject", false);
+
+		try {
+			method = onThis.getClass().getMethod(methodName, null);
+		} catch (NoSuchMethodException e1) {
+			try {
+				method = onThis.getClass().getDeclaredMethod(methodName, null);
+			} catch (NoSuchMethodException e2) {
+				return false;
+			}
+		}
+
+		// Ignore any native code event handling methods
+		if ((method.getModifiers() & Modifier.NATIVE) != 0) {
+			return false;
+		}
+
+		try {
+			method.setAccessible(true);
+			Object result = method.invoke(onThis, null);
+			return true;
+		} catch (InvocationTargetException e) {
+			Qt.qWarning("Invocation failed : " + onThis.getClass().getName() + "." + methodName + "()");
+			e.printStackTrace();
+			return false;
+		} catch (IllegalAccessException e) {
+			Qt.qWarning("Invocation failed : " + onThis.getClass().getName() + "." + methodName + "()");
+			e.printStackTrace();
+			return false;
+		}
+	}
 	/** Invoke the named method on the target object with no arguments. Returns false
 		iff the target method was successfully invoked AND returned false. Unlike the other
 		variants of boolean invoke(), this method returns true if no target java method exists.
 		Used for boolean callbacks such as KMainWindow::queryClose() */
-	public static boolean invoke(long target, String methodName) throws NoSuchMethodException, ClassNotFoundException  {
+	public static boolean booleanInvoke(long target, String methodName) throws NoSuchMethodException, ClassNotFoundException  {
 		Method	method;
 		Object onThis = qtjava.objectForQtKey(target, "QObject", false);
 
@@ -377,6 +412,11 @@ public class Invocation {
 			}
 		}
 
+		// Ignore any native code event handling methods
+		if ((method.getModifiers() & Modifier.NATIVE) != 0) {
+			return true;
+		}
+
 		try {
 			method.setAccessible(true);
 			Object result = method.invoke(onThis, null);
@@ -456,6 +496,11 @@ public class Invocation {
 			return false;
 		}
 
+		// Ignore any native code event handling methods
+		if ((method.getModifiers() & Modifier.NATIVE) != 0) {
+			return false;
+		}
+
 		try {
 			result = (Boolean) method.invoke(onThis, arguments);
 		} catch (InvocationTargetException e) {
